@@ -51,10 +51,12 @@ export interface Tile {
 export interface BaseTile extends Tile {
   allowedGroups: string[],
   activated: boolean,
+  anonymous: boolean,
   selectedGroups: string[],
   backgroundColor: string | null,
   description: Description,
   linkTarget: LinkTarget,
+  originalLinkTarget: LinkTargetOrDefault,
   links: Link[],
   pathToLogo: string,
   key: any, // TODO: no idea how to type this object :(
@@ -70,6 +72,7 @@ export interface Category {
   id: string,
   title: Record<Locale, string>,
   dn: string,
+  virtual: boolean,
   tiles: TileOrFolder[],
 }
 
@@ -99,6 +102,7 @@ export interface PortalFolder {
 export interface PortalCategory {
   dn: string,
   entries: string[],
+  virtual: boolean,
   display_name: LocalizedString,
 }
 
@@ -118,5 +122,7 @@ export interface PortalData {
   entries: PortalEntry[],
   folders: PortalFolder[],
   categories: PortalCategory[],
+  userLinks: string[],
+  menuLinks: string[],
   portal: Portal;
 }
