@@ -27,13 +27,16 @@
  * <https://www.gnu.org/licenses/>.
  */
 
-import { Module } from 'vuex';
+import { Module, ActionContext } from 'vuex';
 
 /* eslint-disable-next-line @typescript-eslint/no-empty-interface */
 export interface RootState {
+  loadingState: boolean,
 }
 
 export type PortalModule<S> = Module<S, RootState>;
+export type PortalActionContext<S> = ActionContext<S, RootState>;
 
 export const initialRootState: RootState = {
+  loadingState: true,
 };
